@@ -8,7 +8,7 @@ from uuid import UUID
 from grpc import RpcError
 
 from preseem import NetworkMetadataReference
-from preseem.source_model import Attachment, Router, Service
+from preseem.source_model import Attachment, Olt, Router, Service
 from preseem_protobuf.model.service_pb2 import SetAttachmentReq
 
 # STM-6039 Only allow the sync to run once at a time, to prevent duplicate
@@ -19,15 +19,6 @@ sync_lock = None
 # algorithm for a given source and intent role.
 ElementSyncItem = namedtuple('ElementSyncItem', ('id', 'name', 'site', 'host'))
 
-
-# Roles are hard-coded here since these should never change.
-class ElementRole:
-    SWITCH = UUID('41f2903a-311a-448d-9d4d-86dc8ba3cb07')
-    AP = UUID('ae3f1aa5-063a-4a24-9744-822a82d107d9')
-    ROUTER = UUID('bf433e28-122b-41df-b49a-77ac6544deac')
-    CPE_RADIO = UUID('c72115d3-daf9-43ae-9475-083d62eae74f')
-
-
 _account_field_map = {
     'type': lambda x: x.type,
     'status': lambda x: x.status,
@@ -42,11 +33,11 @@ _package_field_map = {
     'upload_rate': lambda x: x.upload_rate or None,
 }
 
-_router_field_map = {
+_elem_field_map = {
     'name': lambda x: x.name,
     'management_ip': lambda x: x.host,
     'site_uuid': lambda x: x._site_uuid,
-    'intent_role_uuid': lambda _: ElementRole.ROUTER.bytes,
+    'intent_role_uuid': lambda x: x.role_uuid.bytes,
 }
 
 _service_field_map = {
@@ -205,19 +196,24 @@ async def sync_preseem_model(preseem_model,
         raise ValueError('source cannot be the empty string')
 
     async with sync_lock:
-        model_accounts, model_discs, router_discs, model_services, model_sites, model_packages = await asyncio.gather(
+        model_accounts, model_discs, model_services, model_sites, model_packages = await asyncio.gather(
             preseem_model.Account.List(company_uuid=company_uuid),
-            preseem_model.Element.ListElementDiscovery(company_uuid=company_uuid,
-                                                       intent_role_uuid=role.bytes),
-            preseem_model.Element.ListElementDiscovery(
-                company_uuid=company_uuid, intent_role_uuid=ElementRole.ROUTER.bytes),
+            preseem_model.Element.ListElementDiscovery(company_uuid=company_uuid),
             preseem_model.Service.List(company_uuid=company_uuid,
                                        include_attachment=True),
             preseem_model.Site.List(company_uuid=company_uuid),
             preseem_model.Package.List(company_uuid=company_uuid))
 
         model_sites = {x.uuid: x for x in model_sites}
-        model_discs = {x.uuid: x for x in model_discs}
+
+        role_discs = {}
+        for disc in model_discs:
+            discs = role_discs.get(disc.intent_role_uuid)
+            if discs is None:
+                discs = role_discs[disc.intent_role_uuid] = []
+            discs.append(disc)
+
+        model_discs = {x.uuid: x for x in role_discs.get(role.bytes) or []}
         disc_ids = {(x.source, x.source_id): x for x in model_discs.values()}
 
         # Create a map of name -> site.  Handle multiple sites with the same
@@ -458,54 +454,59 @@ async def sync_preseem_model(preseem_model,
                                 _service_field_map,
                                 noact=noact)
 
-        if routers is not None:
-            assert isinstance(routers, dict)
-            new_sites = set()
-            for router in routers.values():
-                assert isinstance(router, Router)
-                if not router.name:  # name is required for ElementDiscovery
-                    raise ValueError('invalid value for router name')
-                if not router.host:  # host is required for ElementDiscovery
-                    raise ValueError('invalid value for router host')
-                if router.site:
-                    site = site_names.get(router.site)
-                    if not site:
-                        new_sites.add(router.site)
-                    elif site.inactive:
-                        logging.info('sync_preseem_model(%s): reactivate site "%s"',
-                                     source, item.site)
-                        if not noact:
-                            await call_and_log_error(
-                                preseem_model.Site.Update(company_uuid=company_uuid,
-                                                          uuid=site.uuid,
-                                                          inactive=False))
-            for site_name in new_sites:
-                logging.info('sync_preseem_model(%s): create site "%s"', source,
-                             site_name)
-                if not noact:
-                    site = site_names[site_name] = await call_and_log_error(
-                        preseem_model.Site.Create(company_uuid=company_uuid,
-                                                  name=site_name))
-                    if site:
-                        model_sites[site.uuid] = site_names[site_name] = site
+        for bss_objs, source_type in (routers, Router), :
+            if bss_objs is not None:
+                assert isinstance(bss_objs, dict)
+                new_sites = set()
+                for sobj in bss_objs.values():
+                    assert isinstance(sobj, source_type)
+                    if not sobj.name:  # name is required for ElementDiscovery
+                        raise ValueError(
+                            f'invalid value for {source_type.typename} name')
+                    if not sobj.host:  # host is required for ElementDiscovery
+                        raise ValueError(
+                            f'invalid value for {source_type.typename} host')
+                    if sobj.site:
+                        site = site_names.get(sobj.site)
+                        if not site:
+                            new_sites.add(sobj.site)
+                        elif site.inactive:
+                            logging.info('sync_preseem_model(%s): reactivate site "%s"',
+                                         source, item.site)
+                            if not noact:
+                                await call_and_log_error(
+                                    preseem_model.Site.Update(company_uuid=company_uuid,
+                                                              uuid=site.uuid,
+                                                              inactive=False))
+                for site_name in new_sites:
+                    logging.info('sync_preseem_model(%s): create site "%s"', source,
+                                 site_name)
+                    if not noact:
+                        site = site_names[site_name] = await call_and_log_error(
+                            preseem_model.Site.Create(company_uuid=company_uuid,
+                                                      name=site_name))
+                        if site:
+                            model_sites[site.uuid] = site_names[site_name] = site
 
-            for router in routers.values():
-                if router.site:
-                    site = site_names.get(router.site)
-                    router._site_uuid = site.uuid
+                for sobj in bss_objs.values():
+                    if sobj.site:
+                        site = site_names.get(sobj.site)
+                        sobj._site_uuid = site.uuid
 
-            new_objs = await _sync_objects(preseem_model,
-                                           company_uuid,
-                                           source,
-                                           routers,
-                                           router_discs,
-                                           preseem_model.Element.CreateElementDiscovery,
-                                           preseem_model.Element.UpdateElementDiscovery,
-                                           _router_field_map,
-                                           noact=noact)
-            for mobj in router_discs + new_objs:
-                sobj = routers.get(mobj.source_id)
-                if sobj:
-                    sobj._uuid = mobj.uuid
+                discs = [x for x in role_discs.get(source_type.role_uuid.bytes) or []]
+                new_objs = await _sync_objects(
+                    preseem_model,
+                    company_uuid,
+                    source,
+                    bss_objs,
+                    discs,
+                    preseem_model.Element.CreateElementDiscovery,
+                    preseem_model.Element.UpdateElementDiscovery,
+                    _elem_field_map,
+                    noact=noact)
+                for mobj in discs + new_objs:
+                    sobj = bss_objs.get(mobj.source_id)
+                    if sobj:
+                        sobj._uuid = mobj.uuid
 
         return uuid_map
