@@ -568,8 +568,10 @@ class BaseNetworkElement(Errorable):
 class Olt(BaseNetworkElement):
     """OLT class to use within a data source."""
     typename = 'olt'
+    role_uuid = UUID('2d9027d6-8639-40eb-8b65-b86c8ee2238b')
 
 
 class Router(BaseNetworkElement):
     """Router class to use within a data source."""
     typename = 'router'
+    role_uuid = UUID('bf433e28-122b-41df-b49a-77ac6544deac')
