@@ -8,7 +8,7 @@ from uuid import uuid4, UUID
 
 from preseem.preseem_model import BaseModelObject
 from preseem import FakeNetworkMetadataModel, NetworkMetadataReference, FakePreseemModel
-from preseem.model_sync import sync_preseem_model, ElementRole, ElementSyncItem
+from preseem.model_sync import sync_preseem_model, ElementSyncItem
 from preseem_protobuf.model.element_pb2 import ElementStatus
 from preseem_protobuf.model.account_pb2 import AccountType, AccountStatus
 from preseem.source_model import Attachment, Router, Service
@@ -16,6 +16,13 @@ from preseem.source_model import Attachment, Router, Service
 Account = namedtuple('Account', ('id', 'type', 'status', 'name', 'first_name', 'last_name'))
 Package = namedtuple('Package', ('id', 'name', 'download_rate', 'upload_rate'))
 
+class ElementRole:
+    SWITCH = UUID('41f2903a-311a-448d-9d4d-86dc8ba3cb07')
+    AP = UUID('ae3f1aa5-063a-4a24-9744-822a82d107d9')
+    ROUTER = UUID('bf433e28-122b-41df-b49a-77ac6544deac')
+    CPE_RADIO = UUID('c72115d3-daf9-43ae-9475-083d62eae74f')
+
+
 #import logging
 #logging.basicConfig(format='%(message)s', level=logging.INFO)
 
