@@ -3,7 +3,7 @@ import unittest
 from hashlib import sha256
 from uuid import uuid4
 
-from preseem.source_model import Attachment, Router, Service
+from preseem.source_model import Attachment, Olt, Router, Service
 from preseem.grpc_nm_model import NetworkMetadataReference
 
 class TestSourceModel(unittest.TestCase):
@@ -22,7 +22,6 @@ class TestSourceModel(unittest.TestCase):
         self.assertEqual(err.field, field)
         self.assertEqual(err.value, value)
         
-
     def test_router_id(self):
         """Test field checking of router.id"""
         with self.assertRaises(TypeError):
@@ -122,6 +121,16 @@ class TestSourceModel(unittest.TestCase):
         router._uuid = uuid.bytes
         self.assertEqual(router.get_nm('my-system'), [ref])
 
+    def test_olt(self):
+        """Simple unit test for OLT, the code is shared with Router so most of the
+           testing is done there."""
+        olt = Olt("olt1", name='OLT 1', host='192.0.2.2', site='Site 1')
+        ref = NetworkMetadataReference(type='olt', value='olt1', attributes={'host': '192.0.2.2', 'name': 'OLT 1', 'site': 'Site 1', 'system': 'test'})
+        uuid = uuid4()
+        ref.attributes['uuid'] = str(uuid)
+        olt._uuid = uuid.bytes
+        self.assertEqual(olt.get_nm('test'), [ref])
+
     def test_service_id(self):
         """Test field checking of service.id"""
         with self.assertRaises(TypeError):
